@@ -133,10 +133,11 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     /// Delete deanery by ID
     async fn delete_deanery(
         &self,
+        id: uuid::Uuid,
         context: &C) -> Result<DeleteDeaneryResponse, ApiError>
     {
         let context = context.clone();
-        info!("delete_deanery() - X-Span-ID: {:?}", context.get().0.clone());
+        info!("delete_deanery({:?}) - X-Span-ID: {:?}", id, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
@@ -166,11 +167,12 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     /// Update an existing deanery
     async fn update_deanery(
         &self,
+        id: uuid::Uuid,
         deanery: models::Deanery,
         context: &C) -> Result<UpdateDeaneryResponse, ApiError>
     {
         let context = context.clone();
-        info!("update_deanery({:?}) - X-Span-ID: {:?}", deanery, context.get().0.clone());
+        info!("update_deanery({:?}, {:?}) - X-Span-ID: {:?}", id, deanery, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
@@ -188,10 +190,11 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     /// Delete diocese by ID
     async fn delete_diocese(
         &self,
+        id: uuid::Uuid,
         context: &C) -> Result<DeleteDioceseResponse, ApiError>
     {
         let context = context.clone();
-        info!("delete_diocese() - X-Span-ID: {:?}", context.get().0.clone());
+        info!("delete_diocese({:?}) - X-Span-ID: {:?}", id, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
@@ -221,11 +224,12 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     /// Update an existing diocese
     async fn update_diocese(
         &self,
+        id: uuid::Uuid,
         diocese: models::Diocese,
         context: &C) -> Result<UpdateDioceseResponse, ApiError>
     {
         let context = context.clone();
-        info!("update_diocese({:?}) - X-Span-ID: {:?}", diocese, context.get().0.clone());
+        info!("update_diocese({:?}, {:?}) - X-Span-ID: {:?}", id, diocese, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
@@ -243,10 +247,11 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     /// Delete parish by ID
     async fn delete_parish(
         &self,
+        id: uuid::Uuid,
         context: &C) -> Result<DeleteParishResponse, ApiError>
     {
         let context = context.clone();
-        info!("delete_parish() - X-Span-ID: {:?}", context.get().0.clone());
+        info!("delete_parish({:?}) - X-Span-ID: {:?}", id, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
@@ -267,7 +272,7 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
         diocese_name: Option<String>,
         diocese_id: Option<uuid::Uuid>,
         name: Option<String>,
-        offset: Option<uuid::Uuid>,
+        offset: Option<i32>,
         count: Option<i32>,
         context: &C) -> Result<GetParishesResponse, ApiError>
     {
@@ -279,11 +284,12 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     /// Update an existing parish
     async fn update_parish(
         &self,
+        id: uuid::Uuid,
         parish: Option<models::Parish>,
         context: &C) -> Result<UpdateParishResponse, ApiError>
     {
         let context = context.clone();
-        info!("update_parish({:?}) - X-Span-ID: {:?}", parish, context.get().0.clone());
+        info!("update_parish({:?}, {:?}) - X-Span-ID: {:?}", id, parish, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
