@@ -401,7 +401,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/deaneries",
+            "{}/mutation-api/catholic-polity-service/deaneries",
             self.base_path
         );
 
@@ -504,12 +504,14 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn delete_deanery(
         &self,
+        param_id: uuid::Uuid,
         context: &C) -> Result<DeleteDeaneryResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/diocese",
+            "{}/mutation-api/catholic-polity-service/deanery/{id}",
             self.base_path
+            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
 
         // Query parameters
@@ -562,10 +564,22 @@ impl<S, C> Api<C> for Client<S, C> where
             .map_err(|e| ApiError(format!("No response received: {}", e))).await?;
 
         match response.status().as_u16() {
+            200 => {
+                let body = response.into_body();
+                Ok(
+                    DeleteDeaneryResponse::SuccessfulOperation
+                )
+            }
             400 => {
                 let body = response.into_body();
                 Ok(
-                    DeleteDeaneryResponse::InvalidDeaneryValue
+                    DeleteDeaneryResponse::InvalidIDSupplied
+                )
+            }
+            404 => {
+                let body = response.into_body();
+                Ok(
+                    DeleteDeaneryResponse::DeaneryNotFound
                 )
             }
             code => {
@@ -596,7 +610,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/query-api/deaneries",
+            "{}/query-api/catholic-polity-service/deaneries",
             self.base_path
         );
 
@@ -665,7 +679,7 @@ impl<S, C> Api<C> for Client<S, C> where
                         .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
                 let body = str::from_utf8(&body)
                     .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
-                let body = serde_json::from_str::<models::Deanery>(body)?;
+                let body = serde_json::from_str::<models::DeaneryCollection>(body)?;
                 Ok(GetDeaneriesResponse::SuccessfulOperation
                     (body)
                 )
@@ -709,7 +723,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/query-api/deaneries/{id}",
+            "{}/query-api/catholic-polity-service/deaneries/{id}",
             self.base_path
             ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
@@ -810,13 +824,15 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn update_deanery(
         &self,
+        param_id: uuid::Uuid,
         param_deanery: models::Deanery,
         context: &C) -> Result<UpdateDeaneryResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/deanery",
+            "{}/mutation-api/catholic-polity-service/deanery/{id}",
             self.base_path
+            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
 
         // Query parameters
@@ -886,7 +902,7 @@ impl<S, C> Api<C> for Client<S, C> where
                         .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
                 let body = str::from_utf8(&body)
                     .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
-                let body = serde_json::from_str::<models::Parish>(body)?;
+                let body = serde_json::from_str::<models::Deanery>(body)?;
                 Ok(UpdateDeaneryResponse::SuccessfulOperation
                     (body)
                 )
@@ -936,7 +952,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/dioceses",
+            "{}/mutation-api/catholic-polity-service/dioceses",
             self.base_path
         );
 
@@ -1039,12 +1055,14 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn delete_diocese(
         &self,
+        param_id: uuid::Uuid,
         context: &C) -> Result<DeleteDioceseResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/deanery",
+            "{}/mutation-api/catholic-polity-service/diocese/{id}",
             self.base_path
+            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
 
         // Query parameters
@@ -1097,10 +1115,22 @@ impl<S, C> Api<C> for Client<S, C> where
             .map_err(|e| ApiError(format!("No response received: {}", e))).await?;
 
         match response.status().as_u16() {
+            200 => {
+                let body = response.into_body();
+                Ok(
+                    DeleteDioceseResponse::SuccessfulOperation
+                )
+            }
             400 => {
                 let body = response.into_body();
                 Ok(
-                    DeleteDioceseResponse::InvalidDioceseValue
+                    DeleteDioceseResponse::InvalidIDSupplied
+                )
+            }
+            404 => {
+                let body = response.into_body();
+                Ok(
+                    DeleteDioceseResponse::DioceseNotFound
                 )
             }
             code => {
@@ -1130,7 +1160,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/query-api/dioceses/{id}",
+            "{}/query-api/catholic-polity-service/dioceses/{id}",
             self.base_path
             ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
@@ -1237,7 +1267,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/query-api/dioceses",
+            "{}/query-api/catholic-polity-service/dioceses",
             self.base_path
         );
 
@@ -1306,7 +1336,7 @@ impl<S, C> Api<C> for Client<S, C> where
                         .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
                 let body = str::from_utf8(&body)
                     .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
-                let body = serde_json::from_str::<models::Diocese>(body)?;
+                let body = serde_json::from_str::<models::DioceseCollection>(body)?;
                 Ok(GetDiocesesResponse::SuccessfulOperation
                     (body)
                 )
@@ -1345,13 +1375,15 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn update_diocese(
         &self,
+        param_id: uuid::Uuid,
         param_diocese: models::Diocese,
         context: &C) -> Result<UpdateDioceseResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/diocese",
+            "{}/mutation-api/catholic-polity-service/diocese/{id}",
             self.base_path
+            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
 
         // Query parameters
@@ -1421,7 +1453,7 @@ impl<S, C> Api<C> for Client<S, C> where
                         .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
                 let body = str::from_utf8(&body)
                     .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
-                let body = serde_json::from_str::<models::Parish>(body)?;
+                let body = serde_json::from_str::<models::Diocese>(body)?;
                 Ok(UpdateDioceseResponse::SuccessfulOperation
                     (body)
                 )
@@ -1471,7 +1503,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/parishes",
+            "{}/mutation-api/catholic-polity-service/parishes",
             self.base_path
         );
 
@@ -1578,12 +1610,14 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn delete_parish(
         &self,
+        param_id: uuid::Uuid,
         context: &C) -> Result<DeleteParishResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/parish",
+            "{}/mutation-api/catholic-polity-service/parish/{id}",
             self.base_path
+            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
 
         // Query parameters
@@ -1636,10 +1670,22 @@ impl<S, C> Api<C> for Client<S, C> where
             .map_err(|e| ApiError(format!("No response received: {}", e))).await?;
 
         match response.status().as_u16() {
+            200 => {
+                let body = response.into_body();
+                Ok(
+                    DeleteParishResponse::SuccessfulOperation
+                )
+            }
             400 => {
                 let body = response.into_body();
                 Ok(
-                    DeleteParishResponse::InvalidParishValue
+                    DeleteParishResponse::InvalidIDSupplied
+                )
+            }
+            404 => {
+                let body = response.into_body();
+                Ok(
+                    DeleteParishResponse::ParishNotFound
                 )
             }
             code => {
@@ -1669,7 +1715,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/query-api/parishes/{id}",
+            "{}/query-api/catholic-polity-service/parishes/{id}",
             self.base_path
             ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
@@ -1773,13 +1819,13 @@ impl<S, C> Api<C> for Client<S, C> where
         param_diocese_name: Option<String>,
         param_diocese_id: Option<uuid::Uuid>,
         param_name: Option<String>,
-        param_offset: Option<uuid::Uuid>,
+        param_offset: Option<i32>,
         param_count: Option<i32>,
         context: &C) -> Result<GetParishesResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/query-api/parishes",
+            "{}/query-api/catholic-polity-service/parishes",
             self.base_path
         );
 
@@ -1860,7 +1906,7 @@ impl<S, C> Api<C> for Client<S, C> where
                         .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
                 let body = str::from_utf8(&body)
                     .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
-                let body = serde_json::from_str::<models::Parish>(body)?;
+                let body = serde_json::from_str::<models::ParishCollection>(body)?;
                 Ok(GetParishesResponse::SuccessfulOperation
                     (body)
                 )
@@ -1899,13 +1945,15 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn update_parish(
         &self,
+        param_id: uuid::Uuid,
         param_parish: Option<models::Parish>,
         context: &C) -> Result<UpdateParishResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/parish",
+            "{}/mutation-api/catholic-polity-service/parish/{id}",
             self.base_path
+            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
 
         // Query parameters
